@@ -19,9 +19,6 @@ from __future__ import (division as _py3_division,
                         print_function as _py3_print,
                         unicode_literals as _py3_unicode)
 
-__docstring_format__ = 'rst'
-__author__ = 'manu'
-
 import unittest
 from xoutil.decorator import assignment_operator
 from xoutil.decorator.meta import decorator
